==> miniterm-0.0.1.tar.gz: miniterm-0.0.1/src/miniterm.cpp <==
/*
  ^[~i\tg
  Satofumi KAMIMURA
  $Id$
*/

#include "StandardInput.h"
#include "SerialCtrl.h"
#include "SearchFilePath.h"
#include "FileToArgs.h"
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <string>
#include <vector>


static const char* DefaultDevice = "/dev/usb/ttyUSB0";
static const long DefaultBaudrate = 115200;

/*!
  \brief miniterm ̈Ǘ
*/
class ArgsInfo {
public:
  std::string device;
  long baudrate;

  ArgsInfo(void) : device(DefaultDevice), baudrate(DefaultBaudrate) {
  }
};

static void printHelp(char *progName, const char* device, long baudrate) {
  printf("using:\n"
	 "\t%s [--port=%s] [-b=%ld]\n\n",
	 progName, device, baudrate);
}


static void parseArgs(ArgsInfo& args_info, int argc, char* argv[]) {

  for (int i = 1; i < argc; ++i) {
    if (! strncmp("--port=", argv[i], 7)) {
      args_info.device = &argv[i][7];

    } else if (! strncmp("-b=", argv[i], 3)) {
      args_info.baudrate = atoi(&argv[i][3]);

    } else if ((! strcmp("--help", argv[i])) || (! strcmp("-h", argv[i]))) {
      printHelp(argv[0], args_info.device.c_str(), args_info.baudrate);
      exit(1);
    }
  }
}


int main(int argc, char *argv[]) {

  // ݒt@C̓ǂݏo
  std::vector<std::string> search_path;
  search_path.push_back(".");
  search_path.push_back("~/.beego/");

  ArgsInfo args_info;
  std::string config_file;
  if (searchFilePath(config_file, "beegoconf", search_path)) {
    FileToArgs file;
    file.load(config_file.c_str());
    // ݒt@C̓eƂĈ
    parseArgs(args_info, file.argc, file.argv);
  }
  // nꂽ̕]
  parseArgs(args_info, argc, argv);

  // VAڑJ
  SerialCtrl con;
  int ret_value = con.connect(args_info.device.c_str(), args_info.baudrate);
  if (ret_value < 0) {
    printf("%s\n", con.what());
    exit(1);
  }

  // W͂ւ̐ڑJ
  StandardInput sto;

  // ʐM
  char buf[BUFSIZ];
  while (1) {
    int n = con.recv(buf, BUFSIZ, 0);
    if (n > 0) {
      write(1, buf, n);
    }
    n = sto.recv(buf, BUFSIZ, 10);
    if (n > 0) {
      con.send(buf, n);
    }
  }

  return 0;
}

==> miniterm-0.0.3.tar.gz: miniterm-0.0.3/src/miniterm.cpp <==
/*!
  \file
  \brief VAʐM̃^[~i\tg

  \author Satofumi KAMIMURA

  $Id$
*/

#include "StandardInput.h"
#include "SerialCtrl.h"
#include "SearchFilePath.h"
#include "FileToArgs.h"
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <fstream>


static const char* DefaultDevice = "/dev/usb/ttyUSB0";
static const long DefaultBaudrate = 115200;
static const char* LogFileName = "miniterm_log.txt";

/*!
  \brief miniterm ̈Ǘ
*/
class ArgsInfo {
public:
  std::string device;
  long baudrate;
  bool record;

  ArgsInfo(void)
    : device(DefaultDevice), baudrate(DefaultBaudrate), record(false) {
  }
};

static void printHelp(char *progName, const char* device, long baudrate) {
  printf("using:\n"
	 "\t%s [--port=<port>] [-b=<baudrate>] [-r]\n"
	 "\n"
	 "options:\n"
	 "--port=<PORT>\tspecify serial device. (default %s)\n"
	 "-b=<BAUDRATE>\tspecify write baudrate. (default %ld bps)\n"
	 "-r, --record\treceive data record to \"%s\"\n"
	 "\n", progName, device, baudrate, LogFileName);
}


static void parseArgs(ArgsInfo& args_info, int argc, char* argv[]) {

  for (int i = 1; i < argc; ++i) {
    if (! strncmp("--port=", argv[i], 7)) {
      args_info.device = &argv[i][7];

    } else if (! strncmp("-b=", argv[i], 3)) {
      args_info.baudrate = atoi(&argv[i][3]);

    } else if ((! strcmp("--help", argv[i])) || (! strcmp("-h", argv[i]))) {
      printHelp(argv[0], args_info.device.c_str(), args_info.baudrate);
      exit(1);
    } else if ((! strcmp("--record", argv[i])) || (! strcmp("-r", argv[i]))) {
      args_info.record = true;
    }
  }
}


int main(int argc, char *argv[]) {

  // ݒt@C̓ǂݏo
  std::vector<std::string> search_path;
  search_path.push_back(".");
  search_path.push_back("~/.beego/");

  ArgsInfo args_info;
  std::string config_file;
  if (searchFilePath(config_file, "beegoconf", search_path)) {
    FileToArgs file;
    file.load(config_file.c_str());
    // ݒt@C̓eƂĈ
    parseArgs(args_info, file.argc, file.argv);
  }
  // nꂽ̕]
  parseArgs(args_info, argc, argv);

  // VAڑJ
  SerialCtrl con;
  int ret_value = con.connect(args_info.device.c_str(), args_info.baudrate);
  if (ret_value < 0) {
    printf("%s\n", con.what());
    exit(1);
  }

  // L^t@CJ
  std::ofstream fout;
  if (args_info.record) {
    fout.open(LogFileName);
    if (! fout.is_open()) {
      perror(LogFileName);
      args_info.record = false;
    }
  }

  // W͂ւ̐ڑJ
  StandardInput sto;

  // ʐM
  char buf[BUFSIZ];
  while (1) {
    int n = con.recv(buf, BUFSIZ, 0);
    if (n > 0) {
      write(1, buf, n);
      if (args_info.record) {
	// L^t@Cւ̏o
	fout.write(buf, n);
	fout.flush();
      }
    }
    n = sto.recv(buf, BUFSIZ, 10);
    if (n > 0) {
      con.send(buf, n);
    }
  }

  return 0;
}
